@@ -11,10 +11,8 @@ c   This is the interface to draw new volumes.
       record /epPos/ p(*)  ! output.   position given in local coord.
 
 c      
-      if(comp.struc(1:8) .eq. 'cone') then
-         call epDraw_cone(comp, p, n)
-      elseif(comp.struc(1:8) .eq. 'ecyl') then
-         call epDraw_ecyl(comp, p, n)
+      if(comp.struc(1:8) .eq. 'angle') then
+         call epDraw_angle(comp, p, n)
 c---  elseif(comp.struc(1:8) .eq. '%2') then
 c---     call epDraw_%2(comp, p, n)
       else
